package ExampleClass::Subclass;
use strict;
use warnings;
use parent qw(ExampleClass::Base);

=head1 METHODS

=head2 child_method

This is declared in the child class only.

=head2 subclassed_method

This is the child version of the subclassed method.

=cut

1;


